"use client"
import { createFileRequest } from "@/app/lib/kyc/action";
import { IRoute } from "@/types/navigation";

// NextJS Requirement
export const isWindowAvailable = () => typeof window !== "undefined";

export const getBrandTextFromURL = (pathname: string): string => {
  // Split the pathname into segments
  const segments = pathname.split("/").filter(Boolean); // Remove empty segments

  if (segments.includes("edit")) {
    return "Edit"; // Special case for 'edit' pages
  }

  if (segments.includes("view")) {
    return "View"; // Special case for 'view' pages
  }

  if (segments.includes("create")) {
    return "Create"; // Special case for 'create' pages
  }

  // Convert the last segment to title case
  const lastSegment = segments[segments.length - 1];
  return lastSegment.replace(/-/g, " ").replace(/\b\w/g, (char) => char.toUpperCase());
};

export const findCurrentRoute = (routes: IRoute[], pathname: string): IRoute | undefined => {
  for (const route of routes) {
    // Check if the route has children
    if (route.children) {
      // Check child routes first
      for (const child of route.children) {
        const childPath = `${child.layout}${child.path}`;
        if (isWindowAvailable() && pathname === childPath) {
          return child; // Return the child route if it matches exactly
        }
      }
    }

    // Now check the main route
    const mainPath = `${route.layout}${route.path}`;
    if (isWindowAvailable() && pathname === mainPath) {
      return route; // Return the main route if it matches exactly
    }
  }

  return undefined; // No matching route found
};

export const getActiveRoute = (routes: IRoute[], pathname: string): string => {
  const route = findCurrentRoute(routes, pathname);
  return route?.name || "Create";
};

export const getActiveNavbar = (routes: IRoute[], pathname: string): boolean => {
  const route = findCurrentRoute(routes, pathname);
  return route?.secondary;
};

export const getActiveNavbarText = (routes: IRoute[], pathname: string): string | boolean => {
  return getActiveRoute(routes, pathname) || false;
};

// function to check permissions (view, create, edit & delete)
export const hasPermission = (permissions: string[], module: string, action: string): boolean => {
  if (!module) return true;
  if (!action) return false;
  return permissions.some(perm => perm.startsWith(module) && perm.includes(action));
};


export const compareTimes = (timeA: moment.Moment, timeB: moment.Moment) => {
  // Check if the two times are not the same
  if (!timeA.isSame(timeB, 'second')) {
    return true
  } else {
    return false
  }
};


export const getStorage = async (key: string) => {
  if (typeof window !== "undefined") {
    return await JSON.parse(window.localStorage.getItem(key) || null)
  }
}

export const removeStorage = (key: string) => {
  if (typeof window !== "undefined") {
    window.localStorage.removeItem(key)
  }
}

export const setStorage = (key: string, data: any) => {
  if (typeof window !== "undefined") {
    window.localStorage.setItem(key, JSON.stringify(data))
  }
}


